@@ -1,11 +1,19 @@
 from django.conf import settings
 from django.db.models import signals
-from django.db.models.fields import CharField, FloatField, CharField
+from django.db.models.fields import CharField, FloatField, CharField, Field
 
 from django_measurement import measure
 
 MEASURE_OVERRIDES = getattr(settings, 'MEASURE_OVERRIDES', {})
 
+def get_measurement_parts(value):
+    if isinstance(value, measure.UnknownMeasure):
+        return value.get_measurement_parts()
+    measure_name = value.__class__.__name__
+    original_unit = value._default_unit
+    standard_value = getattr(value, value.STANDARD_UNIT)
+    return measure_name, original_unit, standard_value
+
 class MeasurementFieldDescriptor(object):
     def __init__(self, field, measurement_field_name, original_unit_field_name, measure_field_name):
         self.field = field
@@ -20,8 +28,7 @@ class MeasurementFieldDescriptor(object):
             mod = getattr(mod, comp)
         return mod
 
-    def _get_measure(self, instance):
-        measure_name = getattr(instance, self.measure_field_name)
+    def _get_measure_by_name(self, measure_name):
         if measure_name in MEASURE_OVERRIDES:
             return self._get_class_by_path(
                 MEASURE_OVERRIDES[measure_name]
@@ -35,35 +42,46 @@ class MeasurementFieldDescriptor(object):
         if instance is None:
             return self
 
+        measure_name = getattr(
+            instance, 
+            self.measure_field_name
+        )
+        measurement_value = getattr(
+            instance,
+            self.measurement_field_name,
+        )
+        original_unit = getattr(
+            instance,
+            self.original_unit_field_name,
+        )
         try:
-            instance_measure = self._get_measure(instance)
-            measurement_value = getattr(
-                instance,
-                self.measurement_field_name,
-            )
+            instance_measure = self._get_measure_by_name(measure_name)
             measurement = instance_measure(
                 **{instance_measure.STANDARD_UNIT: measurement_value}
             )
-            original_unit = getattr(
-                instance,
-                self.original_unit_field_name,
-            )
             measurement._default_unit = original_unit
-        except (AttributeError, ValueError):
-            return None
+        except (AttributeError, ImportError):
+            measurement = measure.UnknownMeasure(
+                measure=measure_name,
+                original_unit=original_unit,
+                value=measurement_value,
+            )
 
         return measurement
 
     def __set__(self, instance, measurement):
         if instance is None:
             raise AttributeError("Must be accessed via instance")
-        
-        measurement_measure = measurement.__class__.__name__
-        setattr(instance, self.measure_field_name, measurement_measure)
-        setattr(instance, self.original_unit_field_name, measurement._default_unit)
-        setattr(instance, self.measurement_field_name, getattr(measurement, measurement.STANDARD_UNIT, 0))
 
-class MeasurementField(FloatField):
+        measure_name, original_unit, standard_value = get_measurement_parts(
+            measurement
+        )
+        
+        setattr(instance, self.measure_field_name, measure_name)
+        setattr(instance, self.original_unit_field_name, original_unit)
+        setattr(instance, self.measurement_field_name, standard_value)
+
+class MeasurementField(Field):
     def __init__(self, 
             *args,
             **kwargs
@@ -126,9 +144,12 @@ class MeasurementField(FloatField):
     def instance_pre_init(self, signal, sender, args, kwargs, **_kwargs):
         if self.name in kwargs:
             value = kwargs.pop(self.name)
-            kwargs[self.get_original_unit_field_name()] = value._default_unit
-            kwargs[self.get_measure_field_name()] = value.__class__.__name__
-            kwargs[self.get_measurement_field_name()] = getattr(value, value.STANDARD_UNIT, 0)
+            measure_name, original_unit, standard_value = get_measurement_parts(
+                value
+            )
+            kwargs[self.get_measure_field_name()] = measure_name
+            kwargs[self.get_original_unit_field_name()] = original_unit
+            kwargs[self.get_measurement_field_name()] = standard_value
 
 
 try:
